# Bionic

Bionic is a framework for analyzing and modeling data in Python.  It's designed
to help you **iterate faster on your research**, and help your colleagues
**reuse your code more easily**.

Bionic is in alpha and evolving rapidly.  We recommend it for research projects
where the dataset fits in memory.  We do not recommend it for pipelines running
in production.

Check out the [full documentation](https://bionic.readthedocs.io/en/stable/),
or go straight to [Get
Started](https://bionic.readthedocs.io/en/stable/get-started.html).

## Installation

Bionic can be installed from PyPI:

    pip install bionic[standard]

You'll probably want to install [Graphviz](https://www.graphviz.org/) as well.
See the [Installation
docs](https://bionic.readthedocs.io/en/stable/get-started.html#installation)
for more details on installing and configuring Bionic's dependencies.

## Contributing

See the
[Contribution](https://bionic.readthedocs.io/en/stable/contributing.html)
section of our docs.

## License

Copyright 2019 Square, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
